(*

   ############################################################
   #Program: OneLoop.m                                        #
   #Version: 2.0                                              #
   #Date: 05/05/2014                                          #
   #Author: Jorge C. Romao                                    #
   #email: jorge.romao@tecnico.ulisboa                        #
   ############################################################


  This program calculates ALL the scalar one-loop integrals and ALL the 
  tensor one-loop integrals up to NINE Lorentz indices( it can easily be 
  extended). It also calculates the Divergent part of those integrals.
  Conventions are from the appendix to my book paper "Modern Techniques 
  for One-Loop Calculations" 
  (http://porthos.ist.utl.pt/OneLoop/one-loop.ps)  
  and are as follows:

  1) A factor of i/(16 \pi^2) is taken out from all the results. It should be
     put by hand in the end of the calculation. This is also the ususal 
     convention with the Passarino Veltman integrals.
 
  2) To get the scalar integrals one uses the command:
 
     ExpandScalarIntegral[r,m]
 
     where m=number of denominators, r=power of k^2 in the numerator.


  3) To get the tensor integrals one uses the command

     ExpandTensorIntegral[m,mu,nu,...]

     where m=number of denominators, and mu, nu, ... are the indices of 
     the momenta k^{\mu}, k^{\nu}, ... in the numerator. At the moment are 
     only defined the integrals up to 4 Lorentz Indices.

  4) In the results 
     
     delta= 2/\epsilon -\gamma +ln 4\pi

     CC= (\sum_{i=1}{^m-1} x_i r_i)^2 + \sum_{i=1}{^m-1} x_i m_1^2
         -\sum_{i=1}{^m-1} x_i r_i^2 + (1- \sum_{i=1}{^m-1} x_i) m_m^2
         
     where m_i are the masses, r_i the momenta (see appendix) and x_i the
     Feynman parameters. To get a final answer the integration in the Feynman
     parameters has still to be done.


  5) The for vector P^{\mu} is defined in the appendix of my book for
     the different cases.


  6) The integration in the Feynman parameters still has to be
  done. For more then 3 denominators it is best to uese the Passarino
  -Veltman integrals (see the Appendix C of my book)


     where m_i are the masses, r_i the momenta (see appendix) and x_i 
     the Feynman parameters. To get a final answer the integration in 
     the Feynman parameters has still to be done.


  7) To get the divergent part we use the following commands:

      TadpoleDiv[0], TadpoleDiv[a], TadpoleDiv[a,b] ...
      SelfDiv[0], SelfDiv[a], SelfDiv[a,b] ...
      TriangleDiv[0], TriangleDiv[a], TriangleDiv[a,b] ...
      BoxDiv[a,b,c,d]


*)

(* 1. Scalar Integrals *)

ScalarIntegral[r_,m_,eps_]:= \
              (-1)^(r-m) Exp[eta eps/2] (4 Pi  /CC)^(eps/2) CC^(2+r-m) \
               Gamma[2+r-eps/2] / Gamma[2 -eps/2]   \
               Gamma[m-r-2+eps/2] / Gamma[m]

ScalarIntegralAux[r_,m_]:= \
      Normal[Series[ScalarIntegral[r,m,x],{x,0,0}]] /. eta->delta + \
		EulerGamma -2/x -Log[4 Pi]

ExpandScalarIntegral[r_,m_]:=Simplify[ScalarIntegralAux[r,m]]


(* 2. Tensor Integrals *)

(* 2.1 Definition of der[X,P[i]] *)

der[a_ + b_,P[i_]]:=der[a,P[i]]+der[b,P[i]]

der[a_  b_,P[i_]]:=der[a,P[i]] b +a der[b,P[i]]

der[P[i_],P[j_]]:=g[i,j]

der[Exp[-t_ CC],P[i_]]:=-2 t Exp[-t CC] P[i]

der[c_,P[i_]]:=0 /; FreeQ[c,P[i]]


(* 2.2 Tensor Integrals with ONE Lorentz index *)

TensorIntegral[m_,P[i_],eps_]:=(-1)^m Exp[eta eps/2] (4 Pi)^(eps/2)/Gamma[m] \
Integrate[t^(m-3+eps/2) (2 t)^(-1) \
der[Exp[-t CC],P[i]],{t,0,Infinity}, Assumptions->{Re[CC]>0 , Re[eps]>4-2 m}]


Tensoraux[m_,P[i_]]:=Normal[Series[TensorIntegral[m,P[i],x],{x,0,0}]]  \
                  /. eta-> delta + EulerGamma -2/x -Log[4 Pi]

ExpandTensorIntegralAux[m_,P[i_]]:=Simplify[Tensoraux[m,P[i]]]

ExpandTensorIntegral[m_,mu_]:=ExpandTensorIntegralAux[m,P[mu]]


(* 2.3 Tensor Integrals with TWO Lorentz index *)

TensorIntegral[m_,P[i_],P[j_],eps_]:=(-1)^m Exp[eta eps/2] \
        (4 Pi)^(eps/2)/Gamma[m] \
Integrate[t^(m-3+eps/2) (2 t)^(-2) \
der[der[Exp[-t CC],P[i]],P[j]],{t,0,Infinity}, \
Assumptions->{Re[CC]>0, Re[eps]>6-2 m }]

Tensoraux[m_,P[i_],P[j_]]:= \
      Normal[Series[TensorIntegral[m,P[i],P[j],x],{x,0,0}]]  \
                  /. eta-> delta + EulerGamma -2/x -Log[4 Pi]

ExpandTensorIntegralAux[m_,P[i_],P[j_]]:=Simplify[Tensoraux[m,P[i],P[j]]]

ExpandTensorIntegral[m_,mu_,nu_]:=ExpandTensorIntegralAux[m,P[mu],P[nu]]


(* 2.4 Tensor Integrals with THREE Lorentz index *)

TensorIntegral[m_,P[i_],P[j_],P[k_],eps_]:= \
        (-1)^m Exp[eta eps/2] (4 Pi)^(eps/2)/Gamma[m] \
Integrate[t^(m-3+eps/2) (2 t)^(-3) \
der[der[der[Exp[-t CC],P[i]],P[j]],P[k]],{t,0,Infinity}, \
Assumptions->{Re[CC]>0, Re[eps]>6 -2 m}]

Tensoraux[m_,P[i_],P[j_],P[k_]]:= \
      Normal[Series[TensorIntegral[m,P[i],P[j],P[k],x],{x,0,0}]]  \
                  /. eta-> delta + EulerGamma -2/x -Log[4 Pi]

ExpandTensorIntegralAux[m_,P[i_],P[j_],P[k_]]:= \
           Simplify[Tensoraux[m,P[i],P[j],P[k]]]


ExpandTensorIntegral[m_,mu_,nu_,ro_]:= \
   ExpandTensorIntegralAux[m,P[mu],P[nu],P[ro]]

(* 2.5 Tensor Integrals with FOUR Lorentz index *)

TensorIntegral[m_,P[i_],P[j_],P[k_],P[s_],eps_]:= \
        (-1)^m Exp[eta eps/2] (4 Pi)^(eps/2)/Gamma[m] \
Integrate[t^(m-3+eps/2) (2 t)^(-4) \
der[der[der[der[Exp[-t CC],P[i]],P[j]],P[k]],P[s]],{t,0,Infinity}, \
Assumptions->{Re[CC]>0, Re[eps]>8 -2 m}]


Tensoraux[m_,P[i_],P[j_],P[k_],P[s_]]:= \
      Normal[Series[TensorIntegral[m,P[i],P[j],P[k],P[s],x],{x,0,0}]]  \
                  /. eta-> delta + EulerGamma -2/x -Log[4 Pi]

ExpandTensorIntegralAux[m_,P[i_],P[j_],P[k_],P[s_]]:= \
           Simplify[Tensoraux[m,P[i],P[j],P[k],P[s]]]


ExpandTensorIntegral[m_,mu_,nu_,ro_,si_]:= \
   ExpandTensorIntegralAux[m,P[mu],P[nu],P[ro],P[si]]


(* 2.6 Tensor Integrals with FIVE Lorentz index *)

TensorIntegral[m_,P[i_],P[j_],P[k_],P[s_],P[r_],eps_]:= \
        (-1)^m Exp[eta eps/2] (4 Pi)^(eps/2)/Gamma[m] \
Integrate[t^(m-3+eps/2) (2 t)^(-5) \
der[der[der[der[der[Exp[-t CC],P[i]],P[j]],P[k]],P[s]],P[r]],{t,0,Infinity}, \
Assumptions->{Re[CC]>0, Re[eps]>8 -2 m}]


Tensoraux[m_,P[i_],P[j_],P[k_],P[s_],P[r_]]:= \
      Normal[Series[TensorIntegral[m,P[i],P[j],P[k],P[s],P[r],x],{x,0,0}]]  \
                  /. eta-> delta + EulerGamma -2/x -Log[4 Pi]

ExpandTensorIntegralAux[m_,P[i_],P[j_],P[k_],P[s_],P[r_]]:= \
           Simplify[Tensoraux[m,P[i],P[j],P[k],P[s],P[r]]]


ExpandTensorIntegral[m_,mu_,nu_,ro_,si_,al_]:= \
   ExpandTensorIntegralAux[m,P[mu],P[nu],P[ro],P[si],P[al]]


(* 2.7 Tensor Integrals with SIX Lorentz index *)

TensorIntegral[m_,P[i_],P[j_],P[k_],P[s_],P[r_],P[q_],eps_]:= \
        (-1)^m Exp[eta eps/2] (4 Pi)^(eps/2)/Gamma[m] \
Integrate[t^(m-3+eps/2) (2 t)^(-6) \
der[der[der[der[der[der[Exp[-t CC],P[i]],P[j]],P[k]],P[s]],P[r]],P[q]],{t,0,Infinity},Assumptions -> {Re[CC] > 0, Re[eps] > 10 - 2 m}] 


Tensoraux[m_,P[i_],P[j_],P[k_],P[s_],P[r_],P[q_]]:= \
      Normal[Series[TensorIntegral[m,P[i],P[j],P[k],P[s],P[r],P[q],x],{x,0,0}]]  \
                  /. eta-> delta + EulerGamma -2/x -Log[4 Pi]

ExpandTensorIntegralAux[m_,P[i_],P[j_],P[k_],P[s_],P[r_],P[q_]]:= \
           Simplify[Tensoraux[m,P[i],P[j],P[k],P[s],P[r],P[q]]]


ExpandTensorIntegral[m_,mu_,nu_,ro_,si_,al_,be_]:= \
   ExpandTensorIntegralAux[m,P[mu],P[nu],P[ro],P[si],P[al],P[be]]


(* 2.8 Tensor Integrals with SEVEN Lorentz index *)

TensorIntegral[m_,P[i_],P[j_],P[k_],P[s_],P[r_],P[p_],P[q_],eps_]:= \
        (-1)^m Exp[eta eps/2] (4 Pi)^(eps/2)/Gamma[m] \
Integrate[t^(m-3+eps/2) (2 t)^(-7) \
der[der[der[der[der[der[der[Exp[-t CC],P[i]],P[j]],P[k]],P[s]],P[r]],P[p]],P[q]],{t,0,Infinity},Assumptions -> {Re[CC] > 0, Re[eps] > 10 - 2 m}]


Tensoraux[m_,P[i_],P[j_],P[k_],P[s_],P[r_],P[p_],P[q_]]:= \
      Normal[Series[TensorIntegral[m,P[i],P[j],P[k],P[s],P[r],P[p],P[q],x],{x,0,0}]]  \
                  /. eta-> delta + EulerGamma -2/x -Log[4 Pi]

ExpandTensorIntegralAux[m_,P[i_],P[j_],P[k_],P[s_],P[r_],P[p_],P[q_]]:= \
           Simplify[Tensoraux[m,P[i],P[j],P[k],P[s],P[r],P[p],P[q]]]


ExpandTensorIntegral[m_,mu_,nu_,ro_,si_,al_,be_,ga_]:= \
   ExpandTensorIntegralAux[m,P[mu],P[nu],P[ro],P[si],P[al],P[be],P[ga]]


(* 2.9 Tensor Integrals with EIGHT Lorentz index *)

TensorIntegral[m_,P[i_],P[j_],P[k_],P[s_],P[r_],P[p_],P[q_],P[u_],eps_]:= \
        (-1)^m Exp[eta eps/2] (4 Pi)^(eps/2)/Gamma[m] \
Integrate[t^(m-3+eps/2) (2 t)^(-8) \
der[der[der[der[der[der[der[der[Exp[-t CC],P[i]],P[j]],P[k]],P[s]],P[r]],P[p]],P[q]],P[u]],{t,0,Infinity},Assumptions->{Re[CC] > 0, Re[eps] > 12 - 2 m}] 


Tensoraux[m_,P[i_],P[j_],P[k_],P[s_],P[r_],P[p_],P[q_],P[u_]]:= \
      Normal[Series[TensorIntegral[m,P[i],P[j],P[k],P[s],P[r],P[p],P[q],P[u],x],{x,0,0}]]   /. eta-> delta + EulerGamma -2/x -Log[4 Pi]

ExpandTensorIntegralAux[m_,P[i_],P[j_],P[k_],P[s_],P[r_],P[p_],P[q_],P[u_]]:= \
           Simplify[Tensoraux[m,P[i],P[j],P[k],P[s],P[r],P[p],P[q],P[u]]]


ExpandTensorIntegral[m_,mu_,nu_,ro_,si_,al_,be_,ga_,de_]:= \
   ExpandTensorIntegralAux[m,P[mu],P[nu],P[ro],P[si],P[al],P[be],P[ga],P[de]]



(* 2.10 Tensor Integrals with NINE Lorentz index *)

TensorIntegral[m_,P[i_],P[j_],P[k_],P[s_],P[r_],P[p_],P[q_],P[u_],P[v_],eps_]:= (-1)^m Exp[eta eps/2] (4 Pi)^(eps/2)/Gamma[m] \
Integrate[t^(m-3+eps/2) (2 t)^(-9) \
der[der[der[der[der[der[der[der[der[Exp[-t CC],P[i]],P[j]],P[k]],P[s]],P[r]],P[p]],P[q]],P[u]],P[v]],{t,0,Infinity},Assumptions->{Re[CC] > 0, Re[eps] > 12 - 2 m}] 


Tensoraux[m_,P[i_],P[j_],P[k_],P[s_],P[r_],P[p_],P[q_],P[u_],P[v_]]:= \
      Normal[Series[TensorIntegral[m,P[i],P[j],P[k],P[s],P[r],P[p],P[q],P[u],P[v],x],{x,0,0}]] /. eta-> delta + EulerGamma -2/x -Log[4 Pi]

ExpandTensorIntegralAux[m_,P[i_],P[j_],P[k_],P[s_],P[r_],P[p_],P[q_],P[u_],P[v_]]:= Simplify[Tensoraux[m,P[i],P[j],P[k],P[s],P[r],P[p],P[q],P[u],P[v]]]


ExpandTensorIntegral[m_,mu_,nu_,ro_,si_,al_,be_,ga_,de_,ta_]:= \
ExpandTensorIntegralAux[m,P[mu],P[nu],P[ro],P[si],P[al],P[be],P[ga],P[de],P[ta]]


(* 3. Divergent Part of Tadpoles *)


TadpoleDiv[0]:= \
        ( aux=Coefficient[ExpandScalarIntegral[0,1],delta] delta /. \
         CC-> m^2 )          

TadpoleDiv[mu_]:= \
         ( aux=Coefficient[ExpandTensorIntegral[1,mu],delta] delta /. \
           {CC->m^2,P[mu]-> 0} ; Simplify[aux] )          

TadpoleDiv[mu_,nu_]:= \
        (aux=Coefficient[ExpandTensorIntegral[1,mu,nu],delta] delta ; \
         aux1= aux /. {CC->m^2,P[mu]->0,P[nu]->0} ; Simplify[aux1] )          



(* 4. Divergent Part of Self Energies *)


SelfDiv[0]:= ( aux=Coefficient[ExpandScalarIntegral[0,2],delta] delta /. \
              CC->x^2 r1^2 +(1-x) m2^2 +x m1^2 -x r1^2 ;
              Integrate[aux,{x,0,1}] )          

SelfDiv[1]:= ( aux=Coefficient[ExpandScalarIntegral[1,2],delta] delta /. \
              CC->x^2 r1^2 +(1-x) m2^2 +x m1^2 -x r1^2 ;
              Integrate[aux,{x,0,1}] )          

SelfDiv[mu_]:= ( aux=Coefficient[ExpandTensorIntegral[2,mu],delta] delta /. \
                {CC->x^2 r1^2 +(1-x) m2^2 +x m1^2 - x r1^2, \
                P[mu]->x r1[mu]} ; ans=Integrate[aux,{x,0,1}] ; \
                Simplify[ans] )          

SelfDiv[mu_,nu_]:= \
        (aux=Coefficient[ExpandTensorIntegral[2,mu,nu],delta] delta /. \
         {CC->x^2 r1^2 +(1-x) m2^2 +x m1^2 - x r1^2, \
         P[mu]->x r1[mu],P[nu]->x r1[nu]} ; ans=Integrate[aux,{x,0,1}] ; \
         Simplify[ans] )          

SelfDiv[mu_,nu_,ro_]:= \
        (aux=Coefficient[ExpandTensorIntegral[2,mu,nu,ro],delta] delta /. \
         {CC->x^2 r1^2 +(1-x) m2^2 +x m1^2 - x r1^2, \
         P[mu]->x r1[mu],P[nu]->x r1[nu],P[ro]->x r1[ro]}; \
         ans=Integrate[aux,{x,0,1}] ; \
         Simplify[ans] )          


(* 5. Divergent Part of Triangles *)


TriangleDiv[0]:= ( aux=Coefficient[ExpandScalarIntegral[0,3],delta] delta /. \
              CC->x1^2 r1^2 +x2^2 r2^2 +2 x1 x2 r1r2 +x1 m1^2 +x2 m2^2 \
              + (1 -x1 -x2) m3^2 -x1 r1^2 -x2 r2^2 ;
              2 Integrate[aux,{x1,0,1},{x2,0,1-x1}] )          

TriangleDiv[1]:= ( aux=Coefficient[ExpandScalarIntegral[1,3],delta] delta /. \
              CC->x1^2 r1^2 +x2^2 r2^2 +2 x1 x2 r1r2 +x1 m1^2 +x2 m2^2 \
              + (1 -x1 -x2) m3^2 -x1 r1^2 -x2 r2^2 ;
              2 Integrate[aux,{x1,0,1},{x2,0,1-x1}] )          

TriangleDiv[mu_]:= \
	( aux=Coefficient[ExpandTensorIntegral[3,mu],delta] delta /. \
   	{CC->x1^2 r1^2 +x2^2 r2^2 +2 x1 x2 r1r2 +x1 m1^2 +x2 m2^2 \
         + (1 -x1 -x2) m3^2 -x1 r1^2 -x2 r2^2, \
        P[mu]->x1 r1[mu] + x2 r2[mu]} ; \
        ans=2 Integrate[aux,{x1,0,1},{x2,0,1-x1}] ; \
        Simplify[ans] )          

TriangleDiv[mu_,nu_]:= \
        (aux=Coefficient[ExpandTensorIntegral[3,mu,nu],delta] delta /. \
        {CC->x1^2 r1^2 +x2^2 r2^2 +2 x1 x2 r1r2 +x1 m1^2 +x2 m2^2 \
        + (1 -x1 -x2) m3^2 -x1 r1^2 -x2 r2^2, \
        P[mu]->x1 r1[mu] + x2 r2[mu],P[nu]->x1 r1[nu] + x2 r2[nu]} ;\
        ans=2 Integrate[aux,{x1,0,1},{x2,0,1-x1}] ; \
        Simplify[ans] )          

TriangleDiv[mu_,nu_,ro_]:= \
        (aux=Coefficient[ExpandTensorIntegral[3,mu,nu,ro],delta] delta /. \
        {CC->x1^2 r1^2 +x2^2 r2^2 +2 x1 x2 r1r2 +x1 m1^2 +x2 m2^2 \
         + (1 -x1 -x2) m3^2 -x1 r1^2 -x2 r2^2, \
        P[mu]->x1 r1[mu] + x2 r2[mu],P[nu]->x1 r1[nu] + x2 r2[nu], \
        P[ro]->x1 r1[ro] + x2 r2[ro]} ; \
        ans=2 Integrate[aux,{x1,0,1},{x2,0,1-x1}] ; \
        Simplify[ans] )          

TriangleDiv[mu_,nu_,ro_,si_]:= \
        (aux=Coefficient[ExpandTensorIntegral[3,mu,nu,ro,si],delta] delta /. \
        {CC->x1^2 r1^2 +x2^2 r2^2 +2 x1 x2 r1r2 +x1 m1^2 +x2 m2^2 \
         + (1 -x1 -x2) m3^2 -x1 r1^2 -x2 r2^2, \
        P[mu]->x1 r1[mu] + x2 r2[mu],P[nu]->x1 r1[nu] + x2 r2[nu], \
        P[ro]->x1 r1[ro] + x2 r2[ro],P[si]->x1 r1[si] + x2 r2[si]} ; \
        ans=2 Integrate[aux,{x1,0,1},{x2,0,1-x1}] ; \
        Simplify[ans] )          

(* 6. Divergent Part of Boxes *)

subDen4={CC->x1^2 r1^2 +x2^2 r2^2 + x3^2 r3^2 +2 x1 x2 r1r2 + 2 x1 x3 r1r3 + \
         + 2 x2 x3 r2r3 +x1 m1^2 +x2 m2^2 + x3 m3^2\
         + (1 -x1 -x2-x3) m4^2 -x1 r1^2 -x2 r2^2 -x3 r3^2, \
        P[i1]->x1 r1[i1] + x2 r2[i1] +x3 r3[i1], \
        P[i2]->x1 r1[i2] + x2 r2[i2] +x3 r3[i2], \
        P[i3]->x1 r1[i3] + x2 r2[i3]+ x3 r3[i3], \
        P[i4]->x1 r1[i4] + x2 r2[i4] + x3 r3[i4], \
        P[i5]->x1 r1[i5] + x2 r2[i5] + x3 r3[i5]} ;



BoxDiv4=Function[{i1,i2,i3,i4},aux=Coefficient[ExpandTensorIntegral[4,i1,i2,i3,i4],delta] delta ; aux = aux //Simplify; aux = aux /. subDen4; ans=6 Integrate[aux,{x1,0,1},{x2,0,1-x1},{x3,0,1-x1-x2}] ; Simplify[ans] ]


BoxDiv5=Function[{i1,i2,i3,i4,i5},aux=Coefficient[ExpandTensorIntegral[4,i1,i2,i3,i4,i5],delta] delta ; aux=aux//Simplify; aux = aux /. subDen4; ans=6 Integrate[aux,{x1,0,1},{x2,0,1-x1},{x3,0,1-x1-x2}] ; Simplify[ans]]


(* 7. Divergent Part of Pentagon *)

subDen5={CC->x1^2 r1^2 +x2^2 r2^2 + x3^2 r3^2 + + x4^2 r4^2 + \
             2 x1 x2 r1r2 + 2 x1 x3 r1r3 + 2 x1 x4 r1r4 + 2 x2 x3 r2r3 + \
             2 x2 x4 r2r4 + 2 x3 x4 r3r4 + \
             x1 m1^2 +x2 m2^2 + x3 m3^2 + x4 m4^2 +\
           (1 -x1 -x2-x3-x4) m5^2 -x1 r1^2 -x2 r2^2 -x3 r3^2-x4 r4^2, \
        P[i1]->x1 r1[i1] + x2 r2[i1] +x3 r3[i1] + x4 r4[i1], \
        P[i2]->x1 r1[i2] + x2 r2[i2] +x3 r3[i2] + x4 r4[i2], \
        P[i3]->x1 r1[i3] + x2 r2[i3]+ x3 r3[i3] + x4 r4[i3], \
        P[i4]->x1 r1[i4] + x2 r2[i4] + x3 r3[i4] + x4 r4[i4], \
        P[i5]->x1 r1[i5] + x2 r2[i5] + x3 r3[i5] + x4 r4[i5], \
        P[i6]->x1 r1[i6] + x2 r2[i6] + x3 r3[i6] + x4 r4[i6], \
        P[i7]->x1 r1[i7] + x2 r2[i7] + x3 r3[i7] + x4 r4[i7]};

PentagonDiv6=Function[{i1,i2,i3,i4,i5,i6}, aux=Coefficient[ExpandTensorIntegral[5,i1,i2,i3,i4,i5,i6],delta] delta; aux = aux //Simplify; aux = aux /. subDen5; ans=24 Integrate[aux,{x1,0,1},{x2,0,1-x1},{x3,0,1-x1-x2},{x4,0,1-x1-x2-x3}] ;Simplify[ans]]      


PentagonDiv7=Function[{i1,i2,i3,i4,i5,i6,i7},aux=Coefficient[ExpandTensorIntegral[5,i1,i2,i3,i4,i5,i6,i7],delta] delta; aux = aux//Simplify; aux = aux /. subDen5; ans=24 Integrate[aux,{x1,0,1},{x2,0,1-x1},{x3,0,1-x1-x2},{x4,0,1-x1-x2-x3}] ;Simplify[ans] ]      


(* 8. Divergent Part of Hexagon *)

subDen6={CC->x1^2 r1^2 +x2^2 r2^2 + x3^2 r3^2 + x4^2 r4^2 + x5^2 r5^2 + \
             2 x1 x2 r1r2 + 2 x1 x3 r1r3 + 2 x1 x4 r1r4 + 2 x1 x5 r1r5 + \
             2 x2 x3 r2r3 + 2 x2 x4 r2r4 + 2 x2 x5 r2r5 +\
	     2 x3 x4 r3r4 + 2 x3 x5 r3r5 + 2 x4 x5 r4r5 +\
             x1 m1^2 +x2 m2^2 + x3 m3^2 + x4 m4^2 + x5 m5^2 +\
           (1 -x1 -x2-x3-x4-x5) m6^2 -x1 r1^2 -x2 r2^2 -x3 r3^2-x4 r4^2 -\
           x5 r5^2, \
        P[i1]->x1 r1[i1] + x2 r2[i1] + x3 r3[i1] + x4 r4[i1] + x5 r5[i1], \
        P[i2]->x1 r1[i2] + x2 r2[i2] + x3 r3[i2] + x4 r4[i2] + x5 r5[i2], \
        P[i3]->x1 r1[i3] + x2 r2[i3] + x3 r3[i3] + x4 r4[i3] + x5 r5[i3], \
        P[i4]->x1 r1[i4] + x2 r2[i4] + x3 r3[i4] + x4 r4[i4] + x5 r5[i4], \
        P[i5]->x1 r1[i5] + x2 r2[i5] + x3 r3[i5] + x4 r4[i5] + x5 r5[i5], \
        P[i6]->x1 r1[i6] + x2 r2[i6] + x3 r3[i6] + x4 r4[i6] + x5 r5[i6], \
        P[i7]->x1 r1[i7] + x2 r2[i7] + x3 r3[i7] + x4 r4[i7] + x5 r5[i7], \
        P[i8]->x1 r1[i8] + x2 r2[i8] + x3 r3[i8] + x4 r4[i8] + x5 r5[i8], \
        P[i9]->x1 r1[i9] + x2 r2[i9] + x3 r3[i9] + x4 r4[i9] + x5 r5[i9]};

HexagonDiv8=Function[{i1,i2,i3,i4,i5,i6,i7,i8},aux=Coefficient[ExpandTensorIntegral[6,i1,i2,i3,i4,i5,i6,i7,i8],delta] delta //Simplify; aux = aux /. subDen6 ; ans=120 Integrate[aux,{x1,0,1},{x2,0,1-x1},{x3,0,1-x1-x2},{x4,0,1-x1-x2-x3},{x5,0,1-x1-x2-x3-x4}] ;Simplify[ans] ]

HexagonDiv9=Function[{i1,i2,i3,i4,i5,i6,i7,i8,i9},aux=Coefficient[ExpandTensorIntegral[6,i1,i2,i3,i4,i5,i6,i7,i8,i9],delta] delta//Simplify; aux = aux /. subDen6 ; ans=120 Integrate[aux,{x1,0,1},{x2,0,1-x1},{x3,0,1-x1-x2},{x4,0,1-x1-x2-x3},{x5,0,1-x1-x2-x3-x4}] ;Simplify[ans] ]



(* Output Divergent parts to a File *)

If[False,
OneLoopToFeynCalc={g[x_, y_] -> MT[x, y],\
 r1[x_]->FV[r1,x],r2[x_]->FV[r2,x],r3[x_]->FV[r3,x],r4[x_]->FV[r4,x],\
 r5[x_]->FV[r5,x],\
 r1^2->SP[r1,r1],r2^2->SP[r2,r2],r3^2->SP[r3,r3],r4^2->SP[r4,r4],\
 r5^2->SP[r5,r5],\
 r1r2->SP[r1,r2],r1r3->SP[r1,r3],r1r4->SP[r1,r4],r1r5->SP[r1,r5], \
 r2r3->SP[r2,r3], r2r4->SP[r2,r4], r2r5->SP[r2,r5], \
 r3r4->SP[r3,r4], r3r5->SP[r3,r5], r4r5->SP[r4,r5] };


stmp=OpenWrite["DivPart.m"]

Write[stmp, "SelfDiv0=Function[{},",SelfDiv[0] /.OneLoopToFeynCalc ,"]"]
Write[stmp, " "]
Write[stmp, "SelfDiv1=Function[{i1},",SelfDiv[i1] /.OneLoopToFeynCalc ,"]"]
Write[stmp, " "]
Write[stmp, "SelfDiv2=Function[{i1,i2},",SelfDiv[i1,i2] /.OneLoopToFeynCalc ,"]"]
Write[stmp, " "]
Write[stmp, "SelfDiv3=Function[{i1,i2,i3},",SelfDiv[i1,i2,i3] /.OneLoopToFeynCalc ,"]"]

Write[stmp, " "]


Write[stmp, "TriangleDiv1=Function[{i1},",TriangleDiv[i1] /.OneLoopToFeynCalc ,"]"]
Write[stmp, " "]
Write[stmp, "TriangleDiv2=Function[{i1,i2},",TriangleDiv[i1,i2] /.OneLoopToFeynCalc ,"]"]
Write[stmp, " "]
Write[stmp, "TriangleDiv3=Function[{i1,i2,i3},",TriangleDiv[i1,i2,i3] /.OneLoopToFeynCalc ,"]"]
Write[stmp, " "]
Write[stmp, "TriangleDiv4=Function[{i1,i2,i3,i4},",TriangleDiv[i1,i2,i3,i4] /.OneLoopToFeynCalc ,"]"]

Write[stmp, " "]

Write[stmp, "BoxDiv4=Function[{i1,i2,i3,i4},",BoxDiv4[i1,i2,i3,i4] /.OneLoopToFeynCalc,"]"]
Write[stmp, " "]
Write[stmp, "BoxDiv5=Function[{i1,i2,i3,i4,i5},",BoxDiv5[i1,i2,i3,i4,i5] /.OneLoopToFeynCalc,"]"]

Write[stmp, " "]


Write[stmp, "PentagonDiv6=Function[{i1,i2,i3,i4,i5,i6},",PentagonDiv6[i1,i2,i3,i4,i5,i6] /.OneLoopToFeynCalc,"]"]
Write[stmp, " "]
Write[stmp, "PentagonDiv7=Function[{i1,i2,i3,i4,i5,i6,i7},",PentagonDiv7[i1,i2,i3,i4,i5,i6,i7] /.OneLoopToFeynCalc,"]"]

Write[stmp, " "]


Write[stmp, "HexagonDiv8=Function[{i1,i2,i3,i4,i5,i6,i7,i8},",HexagonDiv8[i1,i2,i3,i4,i5,i6,i7,i8] /.OneLoopToFeynCalc,"]"]
Write[stmp, " "]
Write[stmp, "HexagonDiv9=Function[{i1,i2,i3,i4,i5,i6,i7,i8,i9},",HexagonDiv9[i1,i2,i3,i4,i5,i6,i7,i8,i9] /.OneLoopToFeynCalc,"]"]

Write[stmp, " "]

Close[stmp]

]

TimeUsed[]

(* End of Package *)



